@@ -1,4 +1,14 @@
 
+//Slideshow hack to go back from the info button
+slideshowHack = {};
+slideshowHack.referrer = document.referrer
+slideshowHack.back = function (uuid)
+{
+    window.location = slideshowHack.referrer + "#" + uuid;
+    return false;
+};
+
+
 //Show the next slide in the given slideshow
 //OVERRIDE
 mediaShow.next = function (slideshowIndex)
@@ -97,7 +107,9 @@ mediaShow.loadSlide = function (slideshow, slideNumber)
         slideContainer.append(infoDiv);
         
         //INFO: Uncomment this if you want clickable pictures
-        var link = '<a class="media"></a><a class="infoButton" href="'+slide.url+'" title="info">info</a>';
+        //var link = '<a class="media"></a><a class="infoButton" href="'+slide.url+'?came_from='+window.location.href+'" title="info">info</a>';
+        var link = '<a class="media"></a><a class="infoButton" href="'+slide.url+'?clicked_on_info=true" title="info">info</a>';
+        //var link = '<a class="media"></a><a class="infoButton" href="'+slide.url+'" title="info">info</a>';
         if (data.media.type == 'Video' || data.media.type == 'Youtube' || data.media.type == 'Vimeo')
         {
           var link = '<a class="media"></a>';
